@@ -45,6 +45,8 @@ async def _bump_and_poll(
             _error(f"Failed HEAD request to {url}. {str(e)}")
         status = response.status_code
         # FIXME: retry once on 500
+        if status >= 500:
+            _error(f"Server error when requesting {url}")
         if status >= 400:
             break
         else:
@@ -131,7 +133,7 @@ def update(
                 f"Updated {r.name} from {r.old_version} to {r.new_version}"
                 for r in new_releases
             ]
-            output_path.write_text("\n".join(lines))
+            output_path.write_text("\n".join(lines) + "\n")
 
     if not new_releases:
         logger.info("Did not found any updates")
